==> haskell-texmath-0.10.1.1-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-texmath.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: texmath
version: 0.10.1.1
id: texmath-0.10.1.1-Konh5HFuOHW3ZuiFILNs20
key: texmath-0.10.1.1-Konh5HFuOHW3ZuiFILNs20
license: GPL
maintainer: jgm@berkeley.edu
stability: Experimental
homepage: http://github.com/jgm/texmath
synopsis: Conversion between formats used to represent mathematics.
description:
    The texmath library provides functions to read and
    write TeX math, presentation MathML, and OMML (Office
    Math Markup Language, used in Microsoft Office).
    Support is also included for converting math formats
    to Gnu eqn and to pandoc'\''s native format (allowing
    conversion, via pandoc, to a variety of different
    markup formats).  The TeX reader supports basic LaTeX
    and AMS extensions, and it can parse and apply LaTeX
    macros.  (See <http://johnmacfarlane.net/texmath here>
    for a live demo of bidirectional conversion between LaTeX
    and MathML.)
    .
    The package also includes several utility modules which
    may be useful for anyone looking to manipulate either
    TeX math or MathML.  For example, a copy of the MathML
    operator dictionary is included.
    .
    Use the @executable@ flag to install a standalone
    executable, @texmath@, that by default reads a LaTeX
    formula from @stdin@ and writes MathML to @stdout@.
    With flags all the functionality exposed by
    '\''Text.TeXMath'\'' can be accessed through this executable.
    (Use the @--help@ flag for a description of all
    functionality)
    .
    The @texmath@ executable can also be used as a CGI
    script, when renamed as @texmath-cgi@.
    It will expect query parameters for @from@, @to@,
    @input@, and optionally @inline@, and return a JSON
    object with either @error@ and a message or
    @success@ and the converted result.
category: Text
author: John MacFarlane, Matthew Pickering
exposed: True
indefinite: False
exposed-modules:
    Text.TeXMath Text.TeXMath.Readers.MathML
    Text.TeXMath.Readers.MathML.EntityMap
    Text.TeXMath.Readers.MathML.MMLDict Text.TeXMath.Readers.OMML
    Text.TeXMath.Readers.TeX Text.TeXMath.Readers.TeX.Macros
    Text.TeXMath.TeX Text.TeXMath.Types Text.TeXMath.Unicode.Fonts
    Text.TeXMath.Unicode.ToASCII Text.TeXMath.Unicode.ToTeX
    Text.TeXMath.Unicode.ToUnicode Text.TeXMath.Writers.Eqn
    Text.TeXMath.Writers.MathML Text.TeXMath.Writers.OMML
    Text.TeXMath.Writers.Pandoc Text.TeXMath.Writers.TeX
hidden-modules: Text.TeXMath.Compat Text.TeXMath.Shared
                Paths_texmath
abi: 8ce4aa6da86ff96e5ddea37c6f77c291
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/texmath-0.10.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/texmath-0.10.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/texmath-0.10.1.1
hs-libraries: HStexmath-0.10.1.1-Konh5HFuOHW3ZuiFILNs20
depends:
    xml-1.3.14-1QOvnW05iRMh383OQN419
    parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp containers-0.5.10.2
    pandoc-types-1.17.3.1-CjkQCzfxYmYDD4ekOU8LoN
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc base-4.10.1.0
    syb-0.7-3Lq8MQxmYP07qktjI1jxu0
abi-depends: xml-1.3.14-1QOvnW05iRMh383OQN419=a7056b3de174482244e4897529e3aaf7
             parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp=b942a04aec0a266706b2e8e67bd137e3
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             pandoc-types-1.17.3.1-CjkQCzfxYmYDD4ekOU8LoN=903b5da69afc1d7c71611ff2c737f4b9
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             syb-0.7-3Lq8MQxmYP07qktjI1jxu0=f985ea42a9fa578e0f67572a93e19b5d
haddock-interfaces: /usr/share/doc/haskell-texmath/html/texmath.haddock
haddock-html: /usr/share/doc/haskell-texmath/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-texmath-0.10.1.1-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-texmath.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: texmath
version: 0.10.1.1
id: texmath-0.10.1.1-B3fdKjg2IYUHk7CYc3Z6QW
key: texmath-0.10.1.1-B3fdKjg2IYUHk7CYc3Z6QW
license: GPL
maintainer: jgm@berkeley.edu
stability: Experimental
homepage: http://github.com/jgm/texmath
synopsis: Conversion between formats used to represent mathematics.
description:
    The texmath library provides functions to read and
    write TeX math, presentation MathML, and OMML (Office
    Math Markup Language, used in Microsoft Office).
    Support is also included for converting math formats
    to Gnu eqn and to pandoc'\''s native format (allowing
    conversion, via pandoc, to a variety of different
    markup formats).  The TeX reader supports basic LaTeX
    and AMS extensions, and it can parse and apply LaTeX
    macros.  (See <http://johnmacfarlane.net/texmath here>
    for a live demo of bidirectional conversion between LaTeX
    and MathML.)
    .
    The package also includes several utility modules which
    may be useful for anyone looking to manipulate either
    TeX math or MathML.  For example, a copy of the MathML
    operator dictionary is included.
    .
    Use the @executable@ flag to install a standalone
    executable, @texmath@, that by default reads a LaTeX
    formula from @stdin@ and writes MathML to @stdout@.
    With flags all the functionality exposed by
    '\''Text.TeXMath'\'' can be accessed through this executable.
    (Use the @--help@ flag for a description of all
    functionality)
    .
    The @texmath@ executable can also be used as a CGI
    script, when renamed as @texmath-cgi@.
    It will expect query parameters for @from@, @to@,
    @input@, and optionally @inline@, and return a JSON
    object with either @error@ and a message or
    @success@ and the converted result.
category: Text
author: John MacFarlane, Matthew Pickering
exposed: True
indefinite: False
exposed-modules:
    Text.TeXMath Text.TeXMath.Readers.MathML
    Text.TeXMath.Readers.MathML.EntityMap
    Text.TeXMath.Readers.MathML.MMLDict Text.TeXMath.Readers.OMML
    Text.TeXMath.Readers.TeX Text.TeXMath.Readers.TeX.Macros
    Text.TeXMath.TeX Text.TeXMath.Types Text.TeXMath.Unicode.Fonts
    Text.TeXMath.Unicode.ToASCII Text.TeXMath.Unicode.ToTeX
    Text.TeXMath.Unicode.ToUnicode Text.TeXMath.Writers.Eqn
    Text.TeXMath.Writers.MathML Text.TeXMath.Writers.OMML
    Text.TeXMath.Writers.Pandoc Text.TeXMath.Writers.TeX
hidden-modules: Text.TeXMath.Compat Text.TeXMath.Shared
                Paths_texmath
abi: ca05614b0a4e29b50575ec1da4f3117b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/texmath-0.10.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/texmath-0.10.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/texmath-0.10.1.1
hs-libraries: HStexmath-0.10.1.1-B3fdKjg2IYUHk7CYc3Z6QW
depends:
    xml-1.3.14-1QOvnW05iRMh383OQN419
    parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp containers-0.5.10.2
    pandoc-types-1.17.3.1-LxdiUDpSlWhASjoxMYevU9
    mtl-2.2.2-8XubxMJDT8QLsstvlNotkc base-4.10.1.0
    syb-0.7-3Lq8MQxmYP07qktjI1jxu0
abi-depends: xml-1.3.14-1QOvnW05iRMh383OQN419=a7056b3de174482244e4897529e3aaf7
             parsec-3.1.13.0-F9Bf3y6KXh0ILPjymhJoOp=b942a04aec0a266706b2e8e67bd137e3
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             pandoc-types-1.17.3.1-LxdiUDpSlWhASjoxMYevU9=f4f9e3cf1a6c008a584d90b4fa8903f0
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             syb-0.7-3Lq8MQxmYP07qktjI1jxu0=f985ea42a9fa578e0f67572a93e19b5d
haddock-interfaces: /usr/share/doc/haskell-texmath/html/texmath.haddock
haddock-html: /usr/share/doc/haskell-texmath/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
